Module: Google::Apis::HypercomputeclusterV1

Defined in:
lib/google/apis/hypercomputecluster_v1.rb,
lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/service.rb,
lib/google/apis/hypercomputecluster_v1/gem_version.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb

Overview

Cluster Director API

The Cluster Director API lets you deploy, manage, and monitor clusters that run artificial intelligence (AI), machine learning (ML), or high performance computing (HPC) workloads.

Defined Under Namespace

Classes: BootDisk, BucketReference, CancelOperationRequest, CheckClusterHealth, Cluster, ComputeInstance, ComputeInstanceSlurmNodeSet, ComputeResource, ComputeResourceConfig, CreateFilestoreInstance, CreateLoginNode, CreateLustreInstance, CreateNetwork, CreateNodeset, CreateOrchestrator, CreatePartition, CreatePrivateServiceAccess, CreateStorageBucket, DeleteFilestoreInstance, DeleteLoginNode, DeleteLustreInstance, DeleteNetwork, DeleteNodeset, DeleteOrchestrator, DeletePartition, DeletePrivateServiceAccess, DeleteStorageBucket, Empty, ExistingBucketConfig, ExistingFilestoreConfig, ExistingLustreConfig, ExistingNetworkConfig, FileShareConfig, FilestoreReference, GcsAutoclassConfig, GcsHierarchicalNamespaceConfig, HypercomputeClusterService, ListClustersResponse, ListLocationsResponse, ListOperationsResponse, Location, LustreReference, NetworkReference, NetworkResource, NetworkResourceConfig, NewBucketConfig, NewFilestoreConfig, NewFlexStartInstancesConfig, NewLustreConfig, NewNetworkConfig, NewOnDemandInstancesConfig, NewReservedInstancesConfig, NewSpotInstancesConfig, Operation, OperationMetadata, OperationProgress, OperationStep, Orchestrator, SlurmLoginNodes, SlurmNodeSet, SlurmOrchestrator, SlurmPartition, Status, StorageConfig, StorageResource, StorageResourceConfig, UpdateLoginNode, UpdateNodeset, UpdateOrchestrator, UpdatePartition

Constant Summary collapse

GEM_VERSION =

Version of the google-apis-hypercomputecluster_v1 gem

"0.8.0"
GENERATOR_VERSION =

Version of the code generator used to generate this client

"0.19.0"
REVISION =

Revision of the discovery document this client was generated from

"20260606"
VERSION =

Version of the Cluster Director API this client connects to. This is NOT the gem version.

'V1'
AUTH_CLOUD_PLATFORM =

See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.

'https://www.googleapis.com/auth/cloud-platform'