Class: Google::Apis::HypercomputeclusterV1::Cluster

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb

Overview

A collection of virtual machines and connected resources forming a high- performance computing cluster capable of running large-scale, tightly coupled workloads. A cluster combines a set a compute resources that perform computations, storage resources that contain inputs and store outputs, an orchestrator that is responsible for assigning jobs to compute resources, and network resources that connect everything together.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Cluster

Returns a new instance of Cluster.



178
179
180
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 178

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#compute_resourcesHash<String,Google::Apis::HypercomputeclusterV1::ComputeResource>

Optional. Compute resources available to the cluster. Keys specify the ID of the compute resource by which it can be referenced elsewhere, and must conform to RFC-1034 (lower-case, alphanumeric, and at most 63 characters). Corresponds to the JSON property computeResources



116
117
118
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 116

def compute_resources
  @compute_resources
end

#create_timeString

Output only. Time that the cluster was originally created. Corresponds to the JSON property createTime

Returns:

  • (String)


121
122
123
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 121

def create_time
  @create_time
end

#descriptionString

Optional. A description for your cluster. You can use up to 2,048 characters. Corresponds to the JSON property description

Returns:

  • (String)


126
127
128
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 126

def description
  @description
end

#labelsHash<String,String>

Optional. Labels applied to the cluster. Labels can be used to organize clusters and to filter them in queries. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


133
134
135
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 133

def labels
  @labels
end

#nameString

Identifier. Relative resource name of the cluster, in the format projects/project/locations/location/clusters/ cluster`. Corresponds to the JSON propertyname`

Returns:

  • (String)


140
141
142
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 140

def name
  @name
end

#network_resourcesHash<String,Google::Apis::HypercomputeclusterV1::NetworkResource>

Optional. Network resources available to the cluster. Must contain exactly one value. Keys specify the ID of the network resource by which it can be referenced elsewhere, and must conform to RFC-1034 (lower-case, alphanumeric, and at most 63 characters). Corresponds to the JSON property networkResources



148
149
150
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 148

def network_resources
  @network_resources
end

#orchestratorGoogle::Apis::HypercomputeclusterV1::Orchestrator

The component responsible for scheduling and running workloads on the cluster as well as providing the user interface for interacting with the cluster at runtime. Corresponds to the JSON property orchestrator



155
156
157
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 155

def orchestrator
  @orchestrator
end

#reconcilingBoolean Also known as: reconciling?

Output only. Indicates whether changes to the cluster are currently in flight. If this is true, then the current state might not match the cluster's intended state. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


162
163
164
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 162

def reconciling
  @reconciling
end

#storage_resourcesHash<String,Google::Apis::HypercomputeclusterV1::StorageResource>

Optional. Storage resources available to the cluster. Keys specify the ID of the storage resource by which it can be referenced elsewhere, and must conform to RFC-1034 (lower-case, alphanumeric, and at most 63 characters). Corresponds to the JSON property storageResources



171
172
173
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 171

def storage_resources
  @storage_resources
end

#update_timeString

Output only. Time that the cluster was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


176
177
178
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 176

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 183

def update!(**args)
  @compute_resources = args[:compute_resources] if args.key?(:compute_resources)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network_resources = args[:network_resources] if args.key?(:network_resources)
  @orchestrator = args[:orchestrator] if args.key?(:orchestrator)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @storage_resources = args[:storage_resources] if args.key?(:storage_resources)
  @update_time = args[:update_time] if args.key?(:update_time)
end