Class: Google::Apis::HypercomputeclusterV1::ComputeInstanceSlurmNodeSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb

Overview

When set in a SlurmNodeSet, indicates that the nodeset should be backed by Compute Engine VM instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ComputeInstanceSlurmNodeSet

Returns a new instance of ComputeInstanceSlurmNodeSet.



241
242
243
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 241

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#boot_diskGoogle::Apis::HypercomputeclusterV1::BootDisk

A Persistent disk used as the boot disk for a Compute Engine VM instance. Corresponds to the JSON property bootDisk



227
228
229
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 227

def boot_disk
  @boot_disk
end

#labelsHash<String,String>

Optional. Labels that should be applied to each VM instance in the nodeset. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


233
234
235
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 233

def labels
  @labels
end

#startup_scriptString

Optional. Startup script to be run on each VM instance in the nodeset. Max 256KB. Corresponds to the JSON property startupScript

Returns:

  • (String)


239
240
241
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 239

def startup_script
  @startup_script
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



246
247
248
249
250
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 246

def update!(**args)
  @boot_disk = args[:boot_disk] if args.key?(:boot_disk)
  @labels = args[:labels] if args.key?(:labels)
  @startup_script = args[:startup_script] if args.key?(:startup_script)
end