Class: Google::Apis::HypercomputeclusterV1::ComputeResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb

Overview

A resource defining how virtual machines and accelerators should be provisioned for the cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ComputeResource

Returns a new instance of ComputeResource.



263
264
265
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 263

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configGoogle::Apis::HypercomputeclusterV1::ComputeResourceConfig

Describes how a compute resource should be created at runtime. Corresponds to the JSON property config



261
262
263
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 261

def config
  @config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



268
269
270
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 268

def update!(**args)
  @config = args[:config] if args.key?(:config)
end