Class: Google::Apis::HypercomputeclusterV1::CreateLustreInstance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb

Overview

When set in OperationStep, indicates that a new lustre instance should be created.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateLustreInstance

Returns a new instance of CreateLustreInstance.



360
361
362
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 360

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#lustreString

Output only. Name of the Managed Lustre instance, in the format projects/ project/locations/location/instances/instance` Corresponds to the JSON propertylustre`

Returns:

  • (String)


358
359
360
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 358

def lustre
  @lustre
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



365
366
367
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 365

def update!(**args)
  @lustre = args[:lustre] if args.key?(:lustre)
end