Class: Google::Apis::HypercomputeclusterV1::CreateNetwork

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb

Overview

When set in OperationStep, indicates that a new network should be created.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateNetwork

Returns a new instance of CreateNetwork.



381
382
383
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 381

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#networkString

Output only. Name of the network to create, in the format projects/project/ global/networks/network`. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


379
380
381
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 379

def network
  @network
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



386
387
388
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 386

def update!(**args)
  @network = args[:network] if args.key?(:network)
end