Class: Google::Apis::HypercomputeclusterV1::DeleteFilestoreInstance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb

Overview

When set in OperationStep, indicates that a Filestore instance should be deleted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeleteFilestoreInstance

Returns a new instance of DeleteFilestoreInstance.



486
487
488
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 486

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filestoreString

Output only. Name of the Filestore instance, in the format projects/project/ locations/location/instances/instance` Corresponds to the JSON propertyfilestore`

Returns:

  • (String)


484
485
486
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 484

def filestore
  @filestore
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



491
492
493
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 491

def update!(**args)
  @filestore = args[:filestore] if args.key?(:filestore)
end