Class: Google::Apis::HypercomputeclusterV1::DeleteLustreInstance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb

Overview

When set in OperationStep, indicates that a Lustre instance should be deleted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeleteLustreInstance

Returns a new instance of DeleteLustreInstance.



520
521
522
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 520

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#lustreString

Output only. Name of the Managed Lustre instance, in the format projects/ project/locations/location/instances/instance` Corresponds to the JSON propertylustre`

Returns:

  • (String)


518
519
520
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 518

def lustre
  @lustre
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



525
526
527
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 525

def update!(**args)
  @lustre = args[:lustre] if args.key?(:lustre)
end