Class: Google::Apis::HypercomputeclusterV1::DeleteNetwork

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb

Overview

When set in OperationStep, indicates network deletion step with the resource name.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeleteNetwork

Returns a new instance of DeleteNetwork.



540
541
542
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 540

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#networkString

Output only. Name of the network to delete, in the format projects/project/ global/networks/network`. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


538
539
540
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 538

def network
  @network
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



545
546
547
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 545

def update!(**args)
  @network = args[:network] if args.key?(:network)
end