Class: Google::Apis::HypercomputeclusterV1::ExistingLustreConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb

Overview

When set in a StorageResourceConfig, indicates that an existing Managed Lustre instance should be imported.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExistingLustreConfig

Returns a new instance of ExistingLustreConfig.



704
705
706
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 704

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#lustreString

Required. Immutable. Name of the Managed Lustre instance to import, in the format projects/project/locations/location/instances/instance` Corresponds to the JSON propertylustre`

Returns:

  • (String)


702
703
704
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 702

def lustre
  @lustre
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



709
710
711
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 709

def update!(**args)
  @lustre = args[:lustre] if args.key?(:lustre)
end