Class: Google::Apis::HypercomputeclusterV1::NetworkResource
- Inherits:
-
Object
- Object
- Google::Apis::HypercomputeclusterV1::NetworkResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb
Overview
A resource representing a network that connects the various components of a cluster together.
Instance Attribute Summary collapse
-
#config ⇒ Google::Apis::HypercomputeclusterV1::NetworkResourceConfig
Describes how a network resource should be initialized.
-
#network ⇒ Google::Apis::HypercomputeclusterV1::NetworkReference
A reference to a VPC network in Google Compute Engine.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkResource
constructor
A new instance of NetworkResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkResource
Returns a new instance of NetworkResource.
1040 1041 1042 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1040 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config ⇒ Google::Apis::HypercomputeclusterV1::NetworkResourceConfig
Describes how a network resource should be initialized. Each network resource
can either be imported from an existing Google Cloud resource or initialized
when the cluster is created.
Corresponds to the JSON property config
1032 1033 1034 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1032 def config @config end |
#network ⇒ Google::Apis::HypercomputeclusterV1::NetworkReference
A reference to a VPC network in
Google Compute Engine.
Corresponds to the JSON property network
1038 1039 1040 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1038 def network @network end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1045 1046 1047 1048 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1045 def update!(**args) @config = args[:config] if args.key?(:config) @network = args[:network] if args.key?(:network) end |