Class: Google::Apis::HypercomputeclusterV1::NewBucketConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb

Overview

When set in a StorageResourceConfig, indicates that a new Google Cloud Storage bucket should be created.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NewBucketConfig

Returns a new instance of NewBucketConfig.



1106
1107
1108
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1106

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autoclassGoogle::Apis::HypercomputeclusterV1::GcsAutoclassConfig

Message describing Google Cloud Storage autoclass configuration Corresponds to the JSON property autoclass



1088
1089
1090
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1088

def autoclass
  @autoclass
end

#bucketString

Required. Immutable. Name of the Cloud Storage bucket to create. Corresponds to the JSON property bucket

Returns:

  • (String)


1093
1094
1095
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1093

def bucket
  @bucket
end

#hierarchical_namespaceGoogle::Apis::HypercomputeclusterV1::GcsHierarchicalNamespaceConfig

Message describing Google Cloud Storage hierarchical namespace configuration Corresponds to the JSON property hierarchicalNamespace



1098
1099
1100
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1098

def hierarchical_namespace
  @hierarchical_namespace
end

#storage_classString

Optional. Immutable. If set, uses the provided storage class as the bucket's default storage class. Corresponds to the JSON property storageClass

Returns:

  • (String)


1104
1105
1106
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1104

def storage_class
  @storage_class
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1111
1112
1113
1114
1115
1116
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1111

def update!(**args)
  @autoclass = args[:autoclass] if args.key?(:autoclass)
  @bucket = args[:bucket] if args.key?(:bucket)
  @hierarchical_namespace = args[:hierarchical_namespace] if args.key?(:hierarchical_namespace)
  @storage_class = args[:storage_class] if args.key?(:storage_class)
end