Class: Google::Apis::HypercomputeclusterV1::ComputeInstanceSlurmNodeSet
- Inherits:
-
Object
- Object
- Google::Apis::HypercomputeclusterV1::ComputeInstanceSlurmNodeSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb
Overview
When set in a SlurmNodeSet, indicates that the nodeset should be backed by Compute Engine VM instances.
Instance Attribute Summary collapse
-
#boot_disk ⇒ Google::Apis::HypercomputeclusterV1::BootDisk
A Persistent disk used as the boot disk for a Compute Engine VM instance.
-
#labels ⇒ Hash<String,String>
Optional.
-
#startup_script ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ComputeInstanceSlurmNodeSet
constructor
A new instance of ComputeInstanceSlurmNodeSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ComputeInstanceSlurmNodeSet
Returns a new instance of ComputeInstanceSlurmNodeSet.
241 242 243 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 241 def initialize(**args) update!(**args) end |
Instance Attribute Details
#boot_disk ⇒ Google::Apis::HypercomputeclusterV1::BootDisk
A Persistent disk used as the
boot disk for a Compute Engine VM instance.
Corresponds to the JSON property bootDisk
227 228 229 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 227 def boot_disk @boot_disk end |
#labels ⇒ Hash<String,String>
Optional. Labels
that should be applied to each VM instance in the nodeset.
Corresponds to the JSON property labels
233 234 235 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 233 def labels @labels end |
#startup_script ⇒ String
Optional. Startup script to be run on each VM instance in the nodeset. Max 256KB.
Corresponds to the JSON property startupScript
239 240 241 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 239 def startup_script @startup_script end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
246 247 248 249 250 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 246 def update!(**args) @boot_disk = args[:boot_disk] if args.key?(:boot_disk) @labels = args[:labels] if args.key?(:labels) @startup_script = args[:startup_script] if args.key?(:startup_script) end |