Class: Google::Apis::HypercomputeclusterV1::ComputeResource
- Inherits:
-
Object
- Object
- Google::Apis::HypercomputeclusterV1::ComputeResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb
Overview
A resource defining how virtual machines and accelerators should be provisioned for the cluster.
Instance Attribute Summary collapse
-
#config ⇒ Google::Apis::HypercomputeclusterV1::ComputeResourceConfig
Describes how a compute resource should be created at runtime.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ComputeResource
constructor
A new instance of ComputeResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ComputeResource
Returns a new instance of ComputeResource.
262 263 264 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 262 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config ⇒ Google::Apis::HypercomputeclusterV1::ComputeResourceConfig
Describes how a compute resource should be created at runtime.
Corresponds to the JSON property config
260 261 262 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 260 def config @config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
267 268 269 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 267 def update!(**args) @config = args[:config] if args.key?(:config) end |