Class: Google::Apis::HypercomputeclusterV1::CreateFilestoreInstance
- Inherits:
-
Object
- Object
- Google::Apis::HypercomputeclusterV1::CreateFilestoreInstance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb
Overview
When set in OperationStep, indicates that a new filestore instance should be created.
Instance Attribute Summary collapse
-
#filestore ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateFilestoreInstance
constructor
A new instance of CreateFilestoreInstance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreateFilestoreInstance
Returns a new instance of CreateFilestoreInstance.
326 327 328 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 326 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filestore ⇒ String
Output only. Name of the Filestore instance, in the format projects/project/
locations/location/instances/instance`
Corresponds to the JSON propertyfilestore`
324 325 326 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 324 def filestore @filestore end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
331 332 333 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 331 def update!(**args) @filestore = args[:filestore] if args.key?(:filestore) end |