Class: Google::Apis::HypercomputeclusterV1::CreateLustreInstance
- Inherits:
-
Object
- Object
- Google::Apis::HypercomputeclusterV1::CreateLustreInstance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb
Overview
When set in OperationStep, indicates that a new lustre instance should be created.
Instance Attribute Summary collapse
-
#lustre ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateLustreInstance
constructor
A new instance of CreateLustreInstance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreateLustreInstance
Returns a new instance of CreateLustreInstance.
360 361 362 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 360 def initialize(**args) update!(**args) end |
Instance Attribute Details
#lustre ⇒ String
Output only. Name of the Managed Lustre instance, in the format projects/
project/locations/location/instances/instance`
Corresponds to the JSON propertylustre`
358 359 360 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 358 def lustre @lustre end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
365 366 367 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 365 def update!(**args) @lustre = args[:lustre] if args.key?(:lustre) end |