Class: Google::Apis::HypercomputeclusterV1::CreateNetwork

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb

Overview

When set in OperationStep, indicates that a new network should be created.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateNetwork

Returns a new instance of CreateNetwork.



380
381
382
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 380

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#networkString

Output only. Name of the network to create, in the format projects/project/ global/networks/network`. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


378
379
380
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 378

def network
  @network
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



385
386
387
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 385

def update!(**args)
  @network = args[:network] if args.key?(:network)
end