Class: Google::Apis::HypercomputeclusterV1::DeleteLustreInstance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb

Overview

When set in OperationStep, indicates that a Lustre instance should be deleted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeleteLustreInstance

Returns a new instance of DeleteLustreInstance.



519
520
521
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 519

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#lustreString

Output only. Name of the Managed Lustre instance, in the format projects/ project/locations/location/instances/instance` Corresponds to the JSON propertylustre`

Returns:

  • (String)


517
518
519
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 517

def lustre
  @lustre
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



524
525
526
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 524

def update!(**args)
  @lustre = args[:lustre] if args.key?(:lustre)
end