Class: Google::Apis::HypercomputeclusterV1::DeleteLustreInstance
- Inherits:
-
Object
- Object
- Google::Apis::HypercomputeclusterV1::DeleteLustreInstance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb
Overview
When set in OperationStep, indicates that a Lustre instance should be deleted.
Instance Attribute Summary collapse
-
#lustre ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeleteLustreInstance
constructor
A new instance of DeleteLustreInstance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeleteLustreInstance
Returns a new instance of DeleteLustreInstance.
519 520 521 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 519 def initialize(**args) update!(**args) end |
Instance Attribute Details
#lustre ⇒ String
Output only. Name of the Managed Lustre instance, in the format projects/
project/locations/location/instances/instance`
Corresponds to the JSON propertylustre`
517 518 519 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 517 def lustre @lustre end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
524 525 526 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 524 def update!(**args) @lustre = args[:lustre] if args.key?(:lustre) end |