Class: Google::Apis::HypercomputeclusterV1::ExistingFilestoreConfig
- Inherits:
-
Object
- Object
- Google::Apis::HypercomputeclusterV1::ExistingFilestoreConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb
Overview
When set in a StorageResourceConfig, indicates that an existing Filestore instance should be imported.
Instance Attribute Summary collapse
-
#filestore ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExistingFilestoreConfig
constructor
A new instance of ExistingFilestoreConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExistingFilestoreConfig
Returns a new instance of ExistingFilestoreConfig.
681 682 683 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 681 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filestore ⇒ String
Required. Immutable. Name of the Filestore instance to import, in the format
projects/project/locations/location/instances/instance`
Corresponds to the JSON propertyfilestore`
679 680 681 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 679 def filestore @filestore end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
686 687 688 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 686 def update!(**args) @filestore = args[:filestore] if args.key?(:filestore) end |