Class: Google::Apis::HypercomputeclusterV1::ExistingLustreConfig
- Inherits:
-
Object
- Object
- Google::Apis::HypercomputeclusterV1::ExistingLustreConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb
Overview
When set in a StorageResourceConfig, indicates that an existing Managed Lustre instance should be imported.
Instance Attribute Summary collapse
-
#lustre ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExistingLustreConfig
constructor
A new instance of ExistingLustreConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExistingLustreConfig
Returns a new instance of ExistingLustreConfig.
703 704 705 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 703 def initialize(**args) update!(**args) end |
Instance Attribute Details
#lustre ⇒ String
Required. Immutable. Name of the Managed Lustre instance to import, in the
format projects/project/locations/location/instances/instance`
Corresponds to the JSON propertylustre`
701 702 703 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 701 def lustre @lustre end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
708 709 710 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 708 def update!(**args) @lustre = args[:lustre] if args.key?(:lustre) end |