Class: Google::Apis::HypercomputeclusterV1::ExistingNetworkConfig
- Inherits:
-
Object
- Object
- Google::Apis::HypercomputeclusterV1::ExistingNetworkConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb
Overview
When set in a NetworkResourceConfig, indicates that an existing network should be imported.
Instance Attribute Summary collapse
-
#network ⇒ String
Required.
-
#subnetwork ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExistingNetworkConfig
constructor
A new instance of ExistingNetworkConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExistingNetworkConfig
Returns a new instance of ExistingNetworkConfig.
730 731 732 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 730 def initialize(**args) update!(**args) end |
Instance Attribute Details
#network ⇒ String
Required. Immutable. Name of the network to import, in the format projects/
project/global/networks/network`.
Corresponds to the JSON propertynetwork`
722 723 724 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 722 def network @network end |
#subnetwork ⇒ String
Required. Immutable. Particular subnetwork to use, in the format projects/
project/regions/region/subnetworks/subnetwork`.
Corresponds to the JSON propertysubnetwork`
728 729 730 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 728 def subnetwork @subnetwork end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
735 736 737 738 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 735 def update!(**args) @network = args[:network] if args.key?(:network) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) end |