Class: Google::Apis::HypercomputeclusterV1::HypercomputeClusterService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::HypercomputeclusterV1::HypercomputeClusterService
- Defined in:
- lib/google/apis/hypercomputecluster_v1/service.rb
Overview
Cluster Director API
The Cluster Director API allows you to deploy, manage, and monitor clusters that run AI, ML, or HPC workloads.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://hypercomputecluster.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HypercomputeclusterV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_cluster(parent, cluster_object = nil, cluster_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HypercomputeclusterV1::Operation
Creates a new Cluster in a given project and location.
-
#delete_project_location_cluster(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HypercomputeclusterV1::Operation
Deletes a single Cluster.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HypercomputeclusterV1::Empty
Deletes a long-running operation.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HypercomputeclusterV1::Location
Gets information about a location.
-
#get_project_location_cluster(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HypercomputeclusterV1::Cluster
Gets details of a single Cluster.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HypercomputeclusterV1::Operation
Gets the latest state of a long-running operation.
-
#initialize ⇒ HypercomputeClusterService
constructor
A new instance of HypercomputeClusterService.
-
#list_project_location_clusters(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HypercomputeclusterV1::ListClustersResponse
Lists Clusters in a given project and location.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HypercomputeclusterV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HypercomputeclusterV1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_cluster(name, cluster_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HypercomputeclusterV1::Operation
Updates the parameters of a single Cluster.
Constructor Details
#initialize ⇒ HypercomputeClusterService
Returns a new instance of HypercomputeClusterService.
48 49 50 51 52 53 |
# File 'lib/google/apis/hypercomputecluster_v1/service.rb', line 48 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-hypercomputecluster_v1', client_version: Google::Apis::HypercomputeclusterV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
41 42 43 |
# File 'lib/google/apis/hypercomputecluster_v1/service.rb', line 41 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
46 47 48 |
# File 'lib/google/apis/hypercomputecluster_v1/service.rb', line 46 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HypercomputeclusterV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
371 372 373 374 375 376 377 378 379 380 381 |
# File 'lib/google/apis/hypercomputecluster_v1/service.rb', line 371 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::HypercomputeclusterV1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::HypercomputeclusterV1::Empty::Representation command.response_class = Google::Apis::HypercomputeclusterV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_cluster(parent, cluster_object = nil, cluster_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HypercomputeclusterV1::Operation
Creates a new Cluster in a given project and location.
170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/google/apis/hypercomputecluster_v1/service.rb', line 170 def create_project_location_cluster(parent, cluster_object = nil, cluster_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/clusters', ) command.request_representation = Google::Apis::HypercomputeclusterV1::Cluster::Representation command.request_object = cluster_object command.response_representation = Google::Apis::HypercomputeclusterV1::Operation::Representation command.response_class = Google::Apis::HypercomputeclusterV1::Operation command.params['parent'] = parent unless parent.nil? command.query['clusterId'] = cluster_id unless cluster_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_cluster(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HypercomputeclusterV1::Operation
Deletes a single Cluster.
208 209 210 211 212 213 214 215 216 217 |
# File 'lib/google/apis/hypercomputecluster_v1/service.rb', line 208 def delete_project_location_cluster(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::HypercomputeclusterV1::Operation::Representation command.response_class = Google::Apis::HypercomputeclusterV1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HypercomputeclusterV1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
406 407 408 409 410 411 412 413 414 |
# File 'lib/google/apis/hypercomputecluster_v1/service.rb', line 406 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::HypercomputeclusterV1::Empty::Representation command.response_class = Google::Apis::HypercomputeclusterV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HypercomputeclusterV1::Location
Gets information about a location.
75 76 77 78 79 80 81 82 83 |
# File 'lib/google/apis/hypercomputecluster_v1/service.rb', line 75 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::HypercomputeclusterV1::Location::Representation command.response_class = Google::Apis::HypercomputeclusterV1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_cluster(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HypercomputeclusterV1::Cluster
Gets details of a single Cluster.
240 241 242 243 244 245 246 247 248 |
# File 'lib/google/apis/hypercomputecluster_v1/service.rb', line 240 def get_project_location_cluster(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::HypercomputeclusterV1::Cluster::Representation command.response_class = Google::Apis::HypercomputeclusterV1::Cluster command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HypercomputeclusterV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
437 438 439 440 441 442 443 444 445 |
# File 'lib/google/apis/hypercomputecluster_v1/service.rb', line 437 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::HypercomputeclusterV1::Operation::Representation command.response_class = Google::Apis::HypercomputeclusterV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_clusters(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HypercomputeclusterV1::ListClustersResponse
Lists Clusters in a given project and location.
285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/google/apis/hypercomputecluster_v1/service.rb', line 285 def list_project_location_clusters(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/clusters', ) command.response_representation = Google::Apis::HypercomputeclusterV1::ListClustersResponse::Representation command.response_class = Google::Apis::HypercomputeclusterV1::ListClustersResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HypercomputeclusterV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
482 483 484 485 486 487 488 489 490 491 492 493 494 |
# File 'lib/google/apis/hypercomputecluster_v1/service.rb', line 482 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/operations', ) command.response_representation = Google::Apis::HypercomputeclusterV1::ListOperationsResponse::Representation command.response_class = Google::Apis::HypercomputeclusterV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HypercomputeclusterV1::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the [
ListLocationsRequest.name] field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/google/apis/hypercomputecluster_v1/service.rb', line 127 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::HypercomputeclusterV1::ListLocationsResponse::Representation command.response_class = Google::Apis::HypercomputeclusterV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_cluster(name, cluster_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HypercomputeclusterV1::Operation
Updates the parameters of a single Cluster.
329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'lib/google/apis/hypercomputecluster_v1/service.rb', line 329 def patch_project_location_cluster(name, cluster_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::HypercomputeclusterV1::Cluster::Representation command.request_object = cluster_object command.response_representation = Google::Apis::HypercomputeclusterV1::Operation::Representation command.response_class = Google::Apis::HypercomputeclusterV1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |