Class: Google::Apis::HypercomputeclusterV1::NewFilestoreConfig
- Inherits:
-
Object
- Object
- Google::Apis::HypercomputeclusterV1::NewFilestoreConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb
Overview
When set in a StorageResourceConfig, indicates that a new Filestore instance should be created.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#file_shares ⇒ Array<Google::Apis::HypercomputeclusterV1::FileShareConfig>
Required.
-
#filestore ⇒ String
Required.
-
#protocol ⇒ String
Optional.
-
#tier ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NewFilestoreConfig
constructor
A new instance of NewFilestoreConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NewFilestoreConfig
Returns a new instance of NewFilestoreConfig.
1151 1152 1153 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1151 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. Immutable. Description of the instance. Maximum of 2048 characters.
Corresponds to the JSON property description
1126 1127 1128 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1126 def description @description end |
#file_shares ⇒ Array<Google::Apis::HypercomputeclusterV1::FileShareConfig>
Required. Immutable. File system shares on the instance. Exactly one file
share must be specified.
Corresponds to the JSON property fileShares
1132 1133 1134 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1132 def file_shares @file_shares end |
#filestore ⇒ String
Required. Immutable. Name of the Filestore instance to create, in the format
projects/project/locations/location/instances/instance`
Corresponds to the JSON propertyfilestore`
1138 1139 1140 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1138 def filestore @filestore end |
#protocol ⇒ String
Optional. Immutable. Access protocol to use for all file shares in the
instance. Defaults to NFS V3 if not set.
Corresponds to the JSON property protocol
1144 1145 1146 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1144 def protocol @protocol end |
#tier ⇒ String
Required. Immutable. Service tier to use for the instance.
Corresponds to the JSON property tier
1149 1150 1151 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1149 def tier @tier end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1156 1157 1158 1159 1160 1161 1162 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1156 def update!(**args) @description = args[:description] if args.key?(:description) @file_shares = args[:file_shares] if args.key?(:file_shares) @filestore = args[:filestore] if args.key?(:filestore) @protocol = args[:protocol] if args.key?(:protocol) @tier = args[:tier] if args.key?(:tier) end |