Class: Google::Apis::HypercomputeclusterV1::NewFlexStartInstancesConfig
- Inherits:
-
Object
- Object
- Google::Apis::HypercomputeclusterV1::NewFlexStartInstancesConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb
Overview
When set in a ComputeResourceConfig, indicates that VM instances should be created using Flex Start.
Instance Attribute Summary collapse
-
#machine_type ⇒ String
Required.
-
#max_duration ⇒ String
Required.
-
#zone ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NewFlexStartInstancesConfig
constructor
A new instance of NewFlexStartInstancesConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NewFlexStartInstancesConfig
Returns a new instance of NewFlexStartInstancesConfig.
1190 1191 1192 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1190 def initialize(**args) update!(**args) end |
Instance Attribute Details
#machine_type ⇒ String
Required. Immutable. Name of the Compute Engine machine type to use, e.g. n2-standard-2.
Corresponds to the JSON property machineType
1175 1176 1177 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1175 def machine_type @machine_type end |
#max_duration ⇒ String
Required. Immutable. Specifies the time limit for created instances. Instances
will be terminated at the end of this duration.
Corresponds to the JSON property maxDuration
1181 1182 1183 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1181 def max_duration @max_duration end |
#zone ⇒ String
Required. Immutable. Name of the zone in which VM instances should run, e.g.,
us-central1-a. Must be in the same region as the cluster, and must match the
zone of any other resources specified in the cluster.
Corresponds to the JSON property zone
1188 1189 1190 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1188 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1195 1196 1197 1198 1199 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1195 def update!(**args) @machine_type = args[:machine_type] if args.key?(:machine_type) @max_duration = args[:max_duration] if args.key?(:max_duration) @zone = args[:zone] if args.key?(:zone) end |