Class: Google::Apis::HypercomputeclusterV1::NewLustreConfig
- Inherits:
-
Object
- Object
- Google::Apis::HypercomputeclusterV1::NewLustreConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb
Overview
When set in a StorageResourceConfig, indicates that a new Managed Lustre instance should be created.
Instance Attribute Summary collapse
-
#capacity_gb ⇒ Fixnum
Required.
-
#description ⇒ String
Optional.
-
#filesystem ⇒ String
Required.
-
#lustre ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NewLustreConfig
constructor
A new instance of NewLustreConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NewLustreConfig
Returns a new instance of NewLustreConfig.
1232 1233 1234 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1232 def initialize(**args) update!(**args) end |
Instance Attribute Details
#capacity_gb ⇒ Fixnum
Required. Immutable. Storage capacity of the instance in gibibytes (GiB).
Allowed values are between 18000 and 7632000.
Corresponds to the JSON property capacityGb
1211 1212 1213 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1211 def capacity_gb @capacity_gb end |
#description ⇒ String
Optional. Immutable. Description of the Managed Lustre instance. Maximum of
2048 characters.
Corresponds to the JSON property description
1217 1218 1219 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1217 def description @description end |
#filesystem ⇒ String
Required. Immutable. Filesystem name for this instance. This name is used by
client-side tools, including when mounting the instance. Must be 8 characters
or less and can only contain letters and numbers.
Corresponds to the JSON property filesystem
1224 1225 1226 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1224 def filesystem @filesystem end |
#lustre ⇒ String
Required. Immutable. Name of the Managed Lustre instance to create, in the
format projects/project/locations/location/instances/instance`
Corresponds to the JSON propertylustre`
1230 1231 1232 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1230 def lustre @lustre end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1237 1238 1239 1240 1241 1242 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1237 def update!(**args) @capacity_gb = args[:capacity_gb] if args.key?(:capacity_gb) @description = args[:description] if args.key?(:description) @filesystem = args[:filesystem] if args.key?(:filesystem) @lustre = args[:lustre] if args.key?(:lustre) end |