Class: Google::Apis::HypercomputeclusterV1::NewNetworkConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb

Overview

When set in a NetworkResourceConfig, indicates that a new network should be created.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NewNetworkConfig

Returns a new instance of NewNetworkConfig.



1261
1262
1263
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1261

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. Immutable. Description of the network. Maximum of 2048 characters. Corresponds to the JSON property description

Returns:

  • (String)


1253
1254
1255
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1253

def description
  @description
end

#networkString

Required. Immutable. Name of the network to create, in the format projects/ project/global/networks/network`. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


1259
1260
1261
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1259

def network
  @network
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1266
1267
1268
1269
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1266

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @network = args[:network] if args.key?(:network)
end