Class: Google::Apis::HypercomputeclusterV1::NewOnDemandInstancesConfig
- Inherits:
-
Object
- Object
- Google::Apis::HypercomputeclusterV1::NewOnDemandInstancesConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb
Overview
When set in a ComputeResourceConfig, indicates that on-demand (i.e., using the standard provisioning model) VM instances should be created.
Instance Attribute Summary collapse
-
#machine_type ⇒ String
Required.
-
#zone ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NewOnDemandInstancesConfig
constructor
A new instance of NewOnDemandInstancesConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NewOnDemandInstancesConfig
Returns a new instance of NewOnDemandInstancesConfig.
1299 1300 1301 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1299 def initialize(**args) update!(**args) end |
Instance Attribute Details
#machine_type ⇒ String
Required. Immutable. Name of the Compute Engine machine type to use, e.g. n2-standard-2.
Corresponds to the JSON property machineType
1290 1291 1292 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1290 def machine_type @machine_type end |
#zone ⇒ String
Required. Immutable. Name of the zone in which VM instances should run, e.g.,
us-central1-a. Must be in the same region as the cluster, and must match the
zone of any other resources specified in the cluster.
Corresponds to the JSON property zone
1297 1298 1299 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1297 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1304 1305 1306 1307 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1304 def update!(**args) @machine_type = args[:machine_type] if args.key?(:machine_type) @zone = args[:zone] if args.key?(:zone) end |