Class: Google::Apis::HypercomputeclusterV1::OperationStep

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb

Overview

Message describing the status of a single step in a cluster mutation long- running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationStep

Returns a new instance of OperationStep.



1633
1634
1635
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1633

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#check_cluster_healthGoogle::Apis::HypercomputeclusterV1::CheckClusterHealth

When set in OperationStep, indicates that cluster health check should be performed. Corresponds to the JSON property checkClusterHealth



1509
1510
1511
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1509

def check_cluster_health
  @check_cluster_health
end

#create_filestore_instanceGoogle::Apis::HypercomputeclusterV1::CreateFilestoreInstance

When set in OperationStep, indicates that a new filestore instance should be created. Corresponds to the JSON property createFilestoreInstance



1515
1516
1517
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1515

def create_filestore_instance
  @create_filestore_instance
end

#create_login_nodeGoogle::Apis::HypercomputeclusterV1::CreateLoginNode

When set in OperationStep, indicates that a login node should be created. Corresponds to the JSON property createLoginNode



1520
1521
1522
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1520

def 
  @create_login_node
end

#create_lustre_instanceGoogle::Apis::HypercomputeclusterV1::CreateLustreInstance

When set in OperationStep, indicates that a new lustre instance should be created. Corresponds to the JSON property createLustreInstance



1526
1527
1528
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1526

def create_lustre_instance
  @create_lustre_instance
end

#create_networkGoogle::Apis::HypercomputeclusterV1::CreateNetwork

When set in OperationStep, indicates that a new network should be created. Corresponds to the JSON property createNetwork



1531
1532
1533
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1531

def create_network
  @create_network
end

#create_nodesetGoogle::Apis::HypercomputeclusterV1::CreateNodeset

When set in OperationStep, indicates that a nodeset should be created. Corresponds to the JSON property createNodeset



1536
1537
1538
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1536

def create_nodeset
  @create_nodeset
end

#create_orchestratorGoogle::Apis::HypercomputeclusterV1::CreateOrchestrator

When set in OperationStep, indicates that an orchestrator should be created. Corresponds to the JSON property createOrchestrator



1541
1542
1543
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1541

def create_orchestrator
  @create_orchestrator
end

#create_partitionGoogle::Apis::HypercomputeclusterV1::CreatePartition

When set in OperationStep, indicates that a partition should be created. Corresponds to the JSON property createPartition



1546
1547
1548
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1546

def create_partition
  @create_partition
end

#create_private_service_accessGoogle::Apis::HypercomputeclusterV1::CreatePrivateServiceAccess

When set in OperationStep, indicates that a new private service access should be created. Corresponds to the JSON property createPrivateServiceAccess



1552
1553
1554
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1552

def create_private_service_access
  @create_private_service_access
end

#create_storage_bucketGoogle::Apis::HypercomputeclusterV1::CreateStorageBucket

When set in OperationStep, indicates that a new storage bucket should be created. Corresponds to the JSON property createStorageBucket



1558
1559
1560
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1558

def create_storage_bucket
  @create_storage_bucket
end

#delete_filestore_instanceGoogle::Apis::HypercomputeclusterV1::DeleteFilestoreInstance

When set in OperationStep, indicates that a Filestore instance should be deleted. Corresponds to the JSON property deleteFilestoreInstance



1564
1565
1566
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1564

def delete_filestore_instance
  @delete_filestore_instance
end

#delete_login_nodeGoogle::Apis::HypercomputeclusterV1::DeleteLoginNode

When set in OperationStep, indicates that a login node should be deleted. Corresponds to the JSON property deleteLoginNode



1569
1570
1571
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1569

def 
  @delete_login_node
end

#delete_lustre_instanceGoogle::Apis::HypercomputeclusterV1::DeleteLustreInstance

When set in OperationStep, indicates that a Lustre instance should be deleted. Corresponds to the JSON property deleteLustreInstance



1574
1575
1576
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1574

def delete_lustre_instance
  @delete_lustre_instance
end

#delete_networkGoogle::Apis::HypercomputeclusterV1::DeleteNetwork

When set in OperationStep, indicates network deletion step with the resource name. Corresponds to the JSON property deleteNetwork



1580
1581
1582
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1580

def delete_network
  @delete_network
end

#delete_nodesetGoogle::Apis::HypercomputeclusterV1::DeleteNodeset

When set in OperationStep, indicates that a nodeset should be deleted. Corresponds to the JSON property deleteNodeset



1585
1586
1587
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1585

def delete_nodeset
  @delete_nodeset
end

#delete_orchestratorGoogle::Apis::HypercomputeclusterV1::DeleteOrchestrator

When set in OperationStep, indicates that an orchestrator should be deleted. Corresponds to the JSON property deleteOrchestrator



1590
1591
1592
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1590

def delete_orchestrator
  @delete_orchestrator
end

#delete_partitionGoogle::Apis::HypercomputeclusterV1::DeletePartition

When set in OperationStep, indicates that a partition should be deleted. Corresponds to the JSON property deletePartition



1595
1596
1597
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1595

def delete_partition
  @delete_partition
end

#delete_private_service_accessGoogle::Apis::HypercomputeclusterV1::DeletePrivateServiceAccess

When set in OperationStep, indicates private service access deletion step. Corresponds to the JSON property deletePrivateServiceAccess



1600
1601
1602
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1600

def delete_private_service_access
  @delete_private_service_access
end

#delete_storage_bucketGoogle::Apis::HypercomputeclusterV1::DeleteStorageBucket

When set in OperationStep, indicates that Cloud Storage bucket should be deleted. Corresponds to the JSON property deleteStorageBucket



1606
1607
1608
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1606

def delete_storage_bucket
  @delete_storage_bucket
end

#stateString

Output only. State of the operation step. Corresponds to the JSON property state

Returns:

  • (String)


1611
1612
1613
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1611

def state
  @state
end

#update_login_nodeGoogle::Apis::HypercomputeclusterV1::UpdateLoginNode

When set in OperationStep, indicates that a login node should be updated. Corresponds to the JSON property updateLoginNode



1616
1617
1618
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1616

def 
  @update_login_node
end

#update_nodesetGoogle::Apis::HypercomputeclusterV1::UpdateNodeset

When set in OperationStep, indicates that a nodeset should be updated. Corresponds to the JSON property updateNodeset



1621
1622
1623
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1621

def update_nodeset
  @update_nodeset
end

#update_orchestratorGoogle::Apis::HypercomputeclusterV1::UpdateOrchestrator

When set in OperationStep, indicates that an orchestrator should be updated. Corresponds to the JSON property updateOrchestrator



1626
1627
1628
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1626

def update_orchestrator
  @update_orchestrator
end

#update_partitionGoogle::Apis::HypercomputeclusterV1::UpdatePartition

When set in OperationStep, indicates that a partition should be updated. Corresponds to the JSON property updatePartition



1631
1632
1633
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1631

def update_partition
  @update_partition
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1638
1639
1640
1641
1642
1643
1644
1645
1646
1647
1648
1649
1650
1651
1652
1653
1654
1655
1656
1657
1658
1659
1660
1661
1662
1663
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1638

def update!(**args)
  @check_cluster_health = args[:check_cluster_health] if args.key?(:check_cluster_health)
  @create_filestore_instance = args[:create_filestore_instance] if args.key?(:create_filestore_instance)
  @create_login_node = args[:create_login_node] if args.key?(:create_login_node)
  @create_lustre_instance = args[:create_lustre_instance] if args.key?(:create_lustre_instance)
  @create_network = args[:create_network] if args.key?(:create_network)
  @create_nodeset = args[:create_nodeset] if args.key?(:create_nodeset)
  @create_orchestrator = args[:create_orchestrator] if args.key?(:create_orchestrator)
  @create_partition = args[:create_partition] if args.key?(:create_partition)
  @create_private_service_access = args[:create_private_service_access] if args.key?(:create_private_service_access)
  @create_storage_bucket = args[:create_storage_bucket] if args.key?(:create_storage_bucket)
  @delete_filestore_instance = args[:delete_filestore_instance] if args.key?(:delete_filestore_instance)
  @delete_login_node = args[:delete_login_node] if args.key?(:delete_login_node)
  @delete_lustre_instance = args[:delete_lustre_instance] if args.key?(:delete_lustre_instance)
  @delete_network = args[:delete_network] if args.key?(:delete_network)
  @delete_nodeset = args[:delete_nodeset] if args.key?(:delete_nodeset)
  @delete_orchestrator = args[:delete_orchestrator] if args.key?(:delete_orchestrator)
  @delete_partition = args[:delete_partition] if args.key?(:delete_partition)
  @delete_private_service_access = args[:delete_private_service_access] if args.key?(:delete_private_service_access)
  @delete_storage_bucket = args[:delete_storage_bucket] if args.key?(:delete_storage_bucket)
  @state = args[:state] if args.key?(:state)
  @update_login_node = args[:update_login_node] if args.key?(:update_login_node)
  @update_nodeset = args[:update_nodeset] if args.key?(:update_nodeset)
  @update_orchestrator = args[:update_orchestrator] if args.key?(:update_orchestrator)
  @update_partition = args[:update_partition] if args.key?(:update_partition)
end