Class: Google::Apis::HypercomputeclusterV1::Orchestrator

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb

Overview

The component responsible for scheduling and running workloads on the cluster as well as providing the user interface for interacting with the cluster at runtime.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Orchestrator

Returns a new instance of Orchestrator.



1678
1679
1680
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1678

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#slurmGoogle::Apis::HypercomputeclusterV1::SlurmOrchestrator

When set in Orchestrator, indicates that the cluster should use Slurm as the orchestrator. Corresponds to the JSON property slurm



1676
1677
1678
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1676

def slurm
  @slurm
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1683
1684
1685
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1683

def update!(**args)
  @slurm = args[:slurm] if args.key?(:slurm)
end