Class: Google::Apis::HypercomputeclusterV1::SlurmPartition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb

Overview

Configuration for Slurm partitions in the cluster. Partitions are groups of nodesets, and are how clients specify where their workloads should be run.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SlurmPartition

Returns a new instance of SlurmPartition.



1928
1929
1930
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1928

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Required. ID of the partition, which is how users will identify it. Must conform to RFC-1034 (lower- case, alphanumeric, and at most 63 characters). Corresponds to the JSON property id

Returns:

  • (String)


1920
1921
1922
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1920

def id
  @id
end

#node_set_idsArray<String>

Required. IDs of the nodesets that make up this partition. Values must match SlurmNodeSet.id. Corresponds to the JSON property nodeSetIds

Returns:

  • (Array<String>)


1926
1927
1928
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1926

def node_set_ids
  @node_set_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1933
1934
1935
1936
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1933

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @node_set_ids = args[:node_set_ids] if args.key?(:node_set_ids)
end