Class: Google::Apis::HypercomputeclusterV1::SlurmPartition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb

Overview

Configuration for Slurm partitions in the cluster. Partitions are groups of nodesets, and are how clients specify where their workloads should be run.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SlurmPartition

Returns a new instance of SlurmPartition.



1919
1920
1921
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1919

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Required. ID of the partition, which is how users will identify it. Must conform to RFC-1034 (lower- case, alphanumeric, and at most 63 characters). Corresponds to the JSON property id

Returns:

  • (String)


1911
1912
1913
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1911

def id
  @id
end

#node_set_idsArray<String>

Required. IDs of the nodesets that make up this partition. Values must match SlurmNodeSet.id. Corresponds to the JSON property nodeSetIds

Returns:

  • (Array<String>)


1917
1918
1919
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1917

def node_set_ids
  @node_set_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1924
1925
1926
1927
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1924

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @node_set_ids = args[:node_set_ids] if args.key?(:node_set_ids)
end