Class: Google::Apis::HypercomputeclusterV1::StorageConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb

Overview

Description of how a storage resource should be mounted on a VM instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageConfig

Returns a new instance of StorageConfig.



1985
1986
1987
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1985

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Required. ID of the storage resource to mount, which must match a key in the cluster's storage_resources. Corresponds to the JSON property id

Returns:

  • (String)


1977
1978
1979
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1977

def id
  @id
end

#local_mountString

Required. A directory inside the VM instance's file system where the storage resource should be mounted (e.g., /mnt/share). Corresponds to the JSON property localMount

Returns:

  • (String)


1983
1984
1985
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1983

def local_mount
  @local_mount
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1990
1991
1992
1993
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 1990

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @local_mount = args[:local_mount] if args.key?(:local_mount)
end