Class: Google::Apis::HypercomputeclusterV1::StorageResource
- Inherits:
-
Object
- Object
- Google::Apis::HypercomputeclusterV1::StorageResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb
Overview
Represents a form of persistent storage that you can mount onto compute resources in the cluster.
Instance Attribute Summary collapse
-
#bucket ⇒ Google::Apis::HypercomputeclusterV1::BucketReference
A reference to a Google Cloud Storage bucket.
-
#config ⇒ Google::Apis::HypercomputeclusterV1::StorageResourceConfig
Describes how a storage resource should be initialized.
-
#filestore ⇒ Google::Apis::HypercomputeclusterV1::FilestoreReference
A reference to a Filestore instance.
-
#lustre ⇒ Google::Apis::HypercomputeclusterV1::LustreReference
A reference to a Managed Lustre instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StorageResource
constructor
A new instance of StorageResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StorageResource
Returns a new instance of StorageResource.
2035 2036 2037 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2035 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bucket ⇒ Google::Apis::HypercomputeclusterV1::BucketReference
A reference to a Google Cloud Storage
bucket.
Corresponds to the JSON property bucket
2015 2016 2017 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2015 def bucket @bucket end |
#config ⇒ Google::Apis::HypercomputeclusterV1::StorageResourceConfig
Describes how a storage resource should be initialized. Each storage resource
can either be imported from an existing Google Cloud resource or initialized
when the cluster is created.
Corresponds to the JSON property config
2022 2023 2024 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2022 def config @config end |
#filestore ⇒ Google::Apis::HypercomputeclusterV1::FilestoreReference
A reference to a Filestore instance.
Corresponds to the JSON property filestore
2027 2028 2029 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2027 def filestore @filestore end |
#lustre ⇒ Google::Apis::HypercomputeclusterV1::LustreReference
A reference to a Managed Lustre instance.
Corresponds to the JSON property lustre
2033 2034 2035 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2033 def lustre @lustre end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2040 2041 2042 2043 2044 2045 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2040 def update!(**args) @bucket = args[:bucket] if args.key?(:bucket) @config = args[:config] if args.key?(:config) @filestore = args[:filestore] if args.key?(:filestore) @lustre = args[:lustre] if args.key?(:lustre) end |