Class: Google::Apis::HypercomputeclusterV1::StorageResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb

Overview

A resource representing a form of persistent storage that is accessible to compute resources in the cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageResource

Returns a new instance of StorageResource.



2034
2035
2036
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2034

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bucketGoogle::Apis::HypercomputeclusterV1::BucketReference

A reference to a Google Cloud Storage bucket. Corresponds to the JSON property bucket



2014
2015
2016
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2014

def bucket
  @bucket
end

#configGoogle::Apis::HypercomputeclusterV1::StorageResourceConfig

Describes how a storage resource should be initialized. Each storage resource can either be imported from an existing Google Cloud resource or initialized when the cluster is created. Corresponds to the JSON property config



2021
2022
2023
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2021

def config
  @config
end

#filestoreGoogle::Apis::HypercomputeclusterV1::FilestoreReference

A reference to a Filestore instance. Corresponds to the JSON property filestore



2026
2027
2028
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2026

def filestore
  @filestore
end

#lustreGoogle::Apis::HypercomputeclusterV1::LustreReference

A reference to a Managed Lustre instance. Corresponds to the JSON property lustre



2032
2033
2034
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2032

def lustre
  @lustre
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2039
2040
2041
2042
2043
2044
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2039

def update!(**args)
  @bucket = args[:bucket] if args.key?(:bucket)
  @config = args[:config] if args.key?(:config)
  @filestore = args[:filestore] if args.key?(:filestore)
  @lustre = args[:lustre] if args.key?(:lustre)
end