Class: Google::Apis::HypercomputeclusterV1::StorageResource
- Inherits:
-
Object
- Object
- Google::Apis::HypercomputeclusterV1::StorageResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb
Overview
A resource representing a form of persistent storage that is accessible to compute resources in the cluster.
Instance Attribute Summary collapse
-
#bucket ⇒ Google::Apis::HypercomputeclusterV1::BucketReference
A reference to a Google Cloud Storage bucket.
-
#config ⇒ Google::Apis::HypercomputeclusterV1::StorageResourceConfig
Describes how a storage resource should be initialized.
-
#filestore ⇒ Google::Apis::HypercomputeclusterV1::FilestoreReference
A reference to a Filestore instance.
-
#lustre ⇒ Google::Apis::HypercomputeclusterV1::LustreReference
A reference to a Managed Lustre instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StorageResource
constructor
A new instance of StorageResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StorageResource
Returns a new instance of StorageResource.
2025 2026 2027 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2025 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bucket ⇒ Google::Apis::HypercomputeclusterV1::BucketReference
A reference to a Google Cloud Storage
bucket.
Corresponds to the JSON property bucket
2005 2006 2007 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2005 def bucket @bucket end |
#config ⇒ Google::Apis::HypercomputeclusterV1::StorageResourceConfig
Describes how a storage resource should be initialized. Each storage resource
can either be imported from an existing Google Cloud resource or initialized
when the cluster is created.
Corresponds to the JSON property config
2012 2013 2014 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2012 def config @config end |
#filestore ⇒ Google::Apis::HypercomputeclusterV1::FilestoreReference
A reference to a Filestore instance.
Corresponds to the JSON property filestore
2017 2018 2019 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2017 def filestore @filestore end |
#lustre ⇒ Google::Apis::HypercomputeclusterV1::LustreReference
A reference to a Managed Lustre instance.
Corresponds to the JSON property lustre
2023 2024 2025 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2023 def lustre @lustre end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2030 2031 2032 2033 2034 2035 |
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2030 def update!(**args) @bucket = args[:bucket] if args.key?(:bucket) @config = args[:config] if args.key?(:config) @filestore = args[:filestore] if args.key?(:filestore) @lustre = args[:lustre] if args.key?(:lustre) end |