Class: Google::Apis::HypercomputeclusterV1::StorageResourceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb

Overview

Describes how a storage resource should be initialized. Each storage resource can either be imported from an existing Google Cloud resource or initialized when the cluster is created.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageResourceConfig

Returns a new instance of StorageResourceConfig.



2090
2091
2092
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2090

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#existing_bucketGoogle::Apis::HypercomputeclusterV1::ExistingBucketConfig

When set in a StorageResourceConfig, indicates that an existing Google Cloud Storage bucket should be imported. Corresponds to the JSON property existingBucket



2057
2058
2059
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2057

def existing_bucket
  @existing_bucket
end

#existing_filestoreGoogle::Apis::HypercomputeclusterV1::ExistingFilestoreConfig

When set in a StorageResourceConfig, indicates that an existing Filestore instance should be imported. Corresponds to the JSON property existingFilestore



2063
2064
2065
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2063

def existing_filestore
  @existing_filestore
end

#existing_lustreGoogle::Apis::HypercomputeclusterV1::ExistingLustreConfig

When set in a StorageResourceConfig, indicates that an existing Managed Lustre instance should be imported. Corresponds to the JSON property existingLustre



2070
2071
2072
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2070

def existing_lustre
  @existing_lustre
end

#new_bucketGoogle::Apis::HypercomputeclusterV1::NewBucketConfig

When set in a StorageResourceConfig, indicates that a new Google Cloud Storage bucket should be created. Corresponds to the JSON property newBucket



2076
2077
2078
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2076

def new_bucket
  @new_bucket
end

#new_filestoreGoogle::Apis::HypercomputeclusterV1::NewFilestoreConfig

When set in a StorageResourceConfig, indicates that a new Filestore instance should be created. Corresponds to the JSON property newFilestore



2082
2083
2084
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2082

def new_filestore
  @new_filestore
end

#new_lustreGoogle::Apis::HypercomputeclusterV1::NewLustreConfig

When set in a StorageResourceConfig, indicates that a new Managed Lustre instance should be created. Corresponds to the JSON property newLustre



2088
2089
2090
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2088

def new_lustre
  @new_lustre
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2095
2096
2097
2098
2099
2100
2101
2102
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2095

def update!(**args)
  @existing_bucket = args[:existing_bucket] if args.key?(:existing_bucket)
  @existing_filestore = args[:existing_filestore] if args.key?(:existing_filestore)
  @existing_lustre = args[:existing_lustre] if args.key?(:existing_lustre)
  @new_bucket = args[:new_bucket] if args.key?(:new_bucket)
  @new_filestore = args[:new_filestore] if args.key?(:new_filestore)
  @new_lustre = args[:new_lustre] if args.key?(:new_lustre)
end