Class: Google::Apis::HypercomputeclusterV1::StorageResourceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/hypercomputecluster_v1/classes.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb,
lib/google/apis/hypercomputecluster_v1/representations.rb

Overview

Describes how a storage resource should be initialized. Each storage resource can either be imported from an existing Google Cloud resource or initialized when the cluster is created.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageResourceConfig

Returns a new instance of StorageResourceConfig.



2081
2082
2083
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2081

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#existing_bucketGoogle::Apis::HypercomputeclusterV1::ExistingBucketConfig

When set in a StorageResourceConfig, indicates that an existing Google Cloud Storage bucket should be imported. Corresponds to the JSON property existingBucket



2048
2049
2050
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2048

def existing_bucket
  @existing_bucket
end

#existing_filestoreGoogle::Apis::HypercomputeclusterV1::ExistingFilestoreConfig

When set in a StorageResourceConfig, indicates that an existing Filestore instance should be imported. Corresponds to the JSON property existingFilestore



2054
2055
2056
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2054

def existing_filestore
  @existing_filestore
end

#existing_lustreGoogle::Apis::HypercomputeclusterV1::ExistingLustreConfig

When set in a StorageResourceConfig, indicates that an existing Managed Lustre instance should be imported. Corresponds to the JSON property existingLustre



2061
2062
2063
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2061

def existing_lustre
  @existing_lustre
end

#new_bucketGoogle::Apis::HypercomputeclusterV1::NewBucketConfig

When set in a StorageResourceConfig, indicates that a new Google Cloud Storage bucket should be created. Corresponds to the JSON property newBucket



2067
2068
2069
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2067

def new_bucket
  @new_bucket
end

#new_filestoreGoogle::Apis::HypercomputeclusterV1::NewFilestoreConfig

When set in a StorageResourceConfig, indicates that a new Filestore instance should be created. Corresponds to the JSON property newFilestore



2073
2074
2075
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2073

def new_filestore
  @new_filestore
end

#new_lustreGoogle::Apis::HypercomputeclusterV1::NewLustreConfig

When set in a StorageResourceConfig, indicates that a new Managed Lustre instance should be created. Corresponds to the JSON property newLustre



2079
2080
2081
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2079

def new_lustre
  @new_lustre
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2086
2087
2088
2089
2090
2091
2092
2093
# File 'lib/google/apis/hypercomputecluster_v1/classes.rb', line 2086

def update!(**args)
  @existing_bucket = args[:existing_bucket] if args.key?(:existing_bucket)
  @existing_filestore = args[:existing_filestore] if args.key?(:existing_filestore)
  @existing_lustre = args[:existing_lustre] if args.key?(:existing_lustre)
  @new_bucket = args[:new_bucket] if args.key?(:new_bucket)
  @new_filestore = args[:new_filestore] if args.key?(:new_filestore)
  @new_lustre = args[:new_lustre] if args.key?(:new_lustre)
end